@@ -1,5 +1,5 @@
 ## File Name: glm.cluster.R
-## File Version: 0.16
+## File Version: 0.25
 
 
 ##################################################
@@ -20,20 +20,23 @@ glm.cluster <- function( data, formula, cluster, ... )
     return(res)
 }
 ###################################################
-coef.glm.cluster <- function( object, ... ){
-    coef( object$glm_res)
+coef.glm.cluster <- function( object, ... )
+{
+    return( coef(object$glm_res) )
 }
 ####################################################
-vcov.glm.cluster <- function( object, ... ){
-    object$vcov
+vcov.glm.cluster <- function( object, ... )
+{
+    return(object$vcov)
 }
 ####################################################
-summary.glm.cluster <- function( object, ... ){
-    smod <- summary( object$glm_res )
+summary.glm.cluster <- function( object, ... )
+{
+    smod <- summary(object$glm_res )
     csmod <- smod$coefficients
-    csmod[,"Std. Error"] <- sqrt( diag( vcov(object) ))
-    csmod[,"z value"] <-  csmod[,"Estimate"] / csmod[,"Std. Error"]
-    csmod[,"Pr(>|z|)"] <- stats::pnorm( - abs( csmod[,"z value"] ) )*2
+    csmod[,2] <- sqrt( diag(object$vcov) )
+    csmod[,3] <- csmod[,1] / csmod[,2]
+    csmod[,4] <- stats::pnorm( - abs( csmod[,3] ) )*2
     # R2 <- smod$r.squared
     # cat("R^2=", round(R2, 5),"\n\n" )
     print(csmod)
