@@ -1,6 +1,8 @@
 ## File Name: mice.impute.2l.groupmean.R
-## File Version: 0.15
-mice.impute.2l.groupmean <- function (y, ry, x, type, grmeanwarning=TRUE, ...){
+## File Version: 0.16
+
+mice.impute.2l.groupmean <- function (y, ry, x, type, grmeanwarning=TRUE, ...)
+{
     if ( ( ncol(x) > 2 ) & grmeanwarning ){
         warning("\nMore than one variable is requested to be aggregated.\n")
         }
@@ -10,7 +12,6 @@ mice.impute.2l.groupmean <- function (y, ry, x, type, grmeanwarning=TRUE, ...){
     i1 <- match( clusterx, as.numeric( rownames(a1) ) )
     ximp <- a1[i1,,drop=FALSE]  / a2[i1,,drop=FALSE]
     # calculate aggregated values
-    colnames(ximp) <- paste( names(type)[ type %in% c(1,2) ],
-                                    names(type)[ type==-2 ] )
+    colnames(ximp) <- paste( names(type)[ type %in% c(1,2) ], names(type)[ type==-2 ] )
     return(ximp)
 }
